# setwd("C:/Users/nwickelmaier/Nextcloud/Documents/MDS/2023ss/60100_master_thesis/code")

source("functions.R")

# Read data

dat0 <- read.table("../data/rawdata_logfiles_small.csv", sep = ";",
                   header = TRUE)
dat0$date <- as.POSIXct(dat0$date)
dat0$glossar <- ifelse(dat0$artwork == "glossar", 1, 0)

# Remove irrelevant events
dat <- subset(dat0, !(dat0$event %in% c("Start Application",
                                        "Show Application")))

# Add trace variable
dat1 <- add_trace(dat)

# Close events
dat2 <- rbind(close_events(dat1, "move"),
              close_events(dat1, "flipCard"),
              close_events(dat1, "openTopic"),
              close_events(dat1, "openPopup"))
dat2 <- dat2[order(dat2$date.start, dat2$fileId.start), ]
# Remove durations when event spans more than one log file, since they are
# not interpretable
dat2[which(dat2$fileId.start != dat2$fileId.stop), "duration"] <- NA

# Remove all events that do not have a `date.start`
dat2 <- dat2[!is.na(dat2$date.start), ]
rownames(dat2) <- NULL

#summary(dat2)

# Add case variable
dat3 <- add_case(dat2)

# Add event ID
dat3$eventId <- seq_len(nrow(dat3))
dat3 <- dat3[, c("fileId.start", "fileId.stop", "eventId", "case",
                 "trace", "glossar", "event", "artwork",
                 "date.start", "date.stop", "timeMs.start",
                 "timeMs.stop", "duration", "topicNumber", "popup",
                 "x.start", "y.start", "x.stop", "y.stop",
                 "distance", "scale.start", "scale.stop",
                 "scaleSize", "rotation.start", "rotation.stop",
                 "rotationDegree")]

# Add trace for move events
dat4 <- add_trace_moves(dat3)

# Fill in topics

# topics <- read.table("../data/topics.csv", sep = ";", header = TRUE)
# TODO: Add topics to data frame

# Export data
write.table(dat4, "../data/event_logfiles.csv", sep = ";",
            row.names = FALSE)

